#!/bin/bash
# check_file_queues.sh - Nagios plugin
# checks the #files in /var/{spool,log,adm,crash,opt} and subdirectories
# skips NFS-mounted sub dirs and prunes at a depth of 4
#
# by Michael Tosch

set +f
PATH=/bin:/usr/bin:/usr/sbin:/sbin
export PATH

case $1 in
(-*) echo "Usage: $0 [#files]"; exit 3;;
(*[!0-9]*) echo "$0: '$1' is not an integer"; exit 3;;
esac

maxfiles=${1:-1000}

for mtab in /etc/mnttab /etc/mtab /proc/mounts
do
  [ -r $mtab ] && break
done
if [ ! -r $mtab ]
then
  mtab=/tmp/mtab.$$
  trap "rm -f $mtab" 0 HUP INT SYS
  mount | awk '$1~/^\//' > $mtab
fi

nfsmnt=`awk '($2~/^\/var\// && $3=="nfs") {printf " %s ", $2}' $mtab`

rdepth=0
recurse(){
 local i cnt=0
 for i in "$1"/*
 do
  [ -h "$i" ] && continue
  if [ -d "$i" ]; then
   [ $((rdepth++)) -lt 4 ] && [[ $nfsmnt != *" $i "* ]] && recurse "$i"
   ((rdepth--))
  else
   ((cnt++))
  fi
 done
 if [ $cnt -ge $maxfiles ]; then
  echo "WARNING: $1 has $cnt files"
  exit 1
 fi
} 

recurse /var/spool
recurse /var/log
recurse /var/adm
recurse /var/crash
recurse /var/opt
echo "OK: less than $maxfiles files in /var dirs"
